@@ -8,11 +8,12 @@ module Data.UnixTime (
   , parseUnixTimeGMT
   , formatUnixTime
   , formatUnixTimeGMT
+  -- * Format
   , Format
   , webDateFormat
   , mailDateFormat
   -- * Difference time
-  , UnixDiffTime
+  , UnixDiffTime(..)
   , diffUnixTime
   , addUnixDiffTime
   , secondsToUnixDiffTime
