@@ -16,6 +16,11 @@
 #include <time.h>
 #include <locale.h>
 #include <stdlib.h>
+#include <stdio.h>
+
+#if defined(_WIN32)
+#include "win_patch.h"
+#endif // _WIN32
 
 #if THREAD_SAFE
 #if HAVE_XLOCALE_H
@@ -32,7 +37,7 @@ void init_locale() {
     static int initialized = 0;
     if (initialized == 0) {
         setlocale(LC_TIME, "C");
-	initialized == 1;
+        initialized = 1;
     }
 }
 #endif
@@ -44,7 +49,11 @@ void init_locale() {
 char *set_tz_utc() {
     char *tz;
     tz = getenv("TZ");
+#if defined(_WIN32)
+    _patch_setenv("TZ", "UTC", 1);
+#else
     setenv("TZ", "", 1);
+#endif
     tzset();
     return tz;
 }
@@ -55,9 +64,17 @@ char *set_tz_utc() {
  */
 void set_tz(char *local_tz) {
     if (local_tz) {
+#if defined(_WIN32)
+      _patch_setenv("TZ", local_tz, 1);
+#else
       setenv("TZ", local_tz, 1);
+#endif
     } else {
+#if defined(_WIN32)
+      _patch_unsetenv("TZ");
+#else
       unsetenv("TZ");
+#endif
     }
     tzset();
 }
@@ -83,13 +100,6 @@ time_t c_parse_unix_time(char *fmt, char *src) {
  * All rights reserved.
  */
 
-static int
-is_leap(unsigned y)
-{
-  y += 1900;
-  return (y % 4) == 0 && ((y % 100) != 0 || (y % 400) == 0);
-}
-
 static time_t
 timegm (struct tm *tm)
 {
@@ -100,10 +110,10 @@ timegm (struct tm *tm)
   unsigned i;
 
   for (i = 70; i < tm->tm_year; ++i)
-    res += is_leap(i) ? 366 : 365;
+    res += isleap(i + 1900) ? 366 : 365;
 
   for (i = 0; i < tm->tm_mon; ++i)
-    res += ndays[is_leap(tm->tm_year)][i];
+    res += ndays[isleap(tm->tm_year + 1900)][i];
   res += tm->tm_mday - 1;
   res *= 24;
   res += tm->tm_hour;
@@ -135,9 +145,17 @@ size_t c_format_unix_time(char *fmt, time_t src, char* dst, int siz) {
     init_locale();
     localtime_r(&src, &tim);
 #if THREAD_SAFE
+#if defined(_WIN32)
+    return _patch_strftime_l(dst, siz, fmt, &tim, c_locale);
+#else
     return strftime_l(dst, siz, fmt, &tim, c_locale);
+#endif // _WIN32
+#else
+#if defined(_WIN32)
+    return _patch_strftime(dst, siz, fmt, &tim);
 #else
     return strftime(dst, siz, fmt, &tim);
+#endif // _WIN32
 #endif
 }
 
@@ -151,9 +169,17 @@ size_t c_format_unix_time_gmt(char *fmt, time_t src, char* dst, int siz) {
 
     local_tz = set_tz_utc();
 #if THREAD_SAFE
+#if defined(_WIN32)
+    dst_size = _patch_strftime_l(dst, siz, fmt, &tim, c_locale);
+#else
     dst_size = strftime_l(dst, siz, fmt, &tim, c_locale);
+#endif // _WIN32
+#else
+#if defined(_WIN32)
+    dst_size = _patch_strftime(dst, siz, fmt, &tim);
 #else
     dst_size = strftime(dst, siz, fmt, &tim);
+#endif // _WIN32
 #endif
     set_tz(local_tz);
     return dst_size;
